[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/aiida-phonopy/aiida-phonopy/develop.svg)](https://results.pre-commit.ci/latest/github/aiida-phonopy/aiida-phonopy/develop)

# AiiDA Phonopy plugin

This a phonopy plugin for AiiDA. This plugin includes workflows to calculate
phonons with supercell and finite displacement approaches. Currently VASP and QE
are supported.
